intensity\_normalization.normalize package
==========================================

Submodules
----------

intensity\_normalization.normalize.base module
----------------------------------------------

.. automodule:: intensity_normalization.normalize.base
   :members:
   :undoc-members:
   :show-inheritance:

intensity\_normalization.normalize.fcm module
---------------------------------------------

.. automodule:: intensity_normalization.normalize.fcm
   :members:
   :undoc-members:
   :show-inheritance:

intensity\_normalization.normalize.kde module
---------------------------------------------

.. automodule:: intensity_normalization.normalize.kde
   :members:
   :undoc-members:
   :show-inheritance:

intensity\_normalization.normalize.lsq module
---------------------------------------------

.. automodule:: intensity_normalization.normalize.lsq
   :members:
   :undoc-members:
   :show-inheritance:

intensity\_normalization.normalize.nyul module
----------------------------------------------

.. automodule:: intensity_normalization.normalize.nyul
   :members:
   :undoc-members:
   :show-inheritance:

intensity\_normalization.normalize.ravel module
-----------------------------------------------

.. automodule:: intensity_normalization.normalize.ravel
   :members:
   :undoc-members:
   :show-inheritance:

intensity\_normalization.normalize.whitestripe module
-----------------------------------------------------

.. automodule:: intensity_normalization.normalize.whitestripe
   :members:
   :undoc-members:
   :show-inheritance:

intensity\_normalization.normalize.zscore module
------------------------------------------------

.. automodule:: intensity_normalization.normalize.zscore
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: intensity_normalization.normalize
   :members:
   :undoc-members:
   :show-inheritance:
